<?php

/**
 * 
 * 2009-08-24 template_directReply.php
 *
 * @author Mariusz Chwalba <koder@mediasystems.pl>
 * @copyright 2009 Media Systems
 * @package cashbill
 * 
 * @page templates Gotowe Szablony
 * @section template_delayedReply Opóźniona odpowiedź na SMS
 * 
 * Ten szablon powinien być stosowany dla usług, w których klient wysyłając SMS rejestruje się
 * w usłudze, która w późniejszym terminie wyśle do niego z góry określoną treść lub treści.
 * Partner otrzymuje kompletną informację o SMS wysłanym przez klienta i na jej podstawie decyduje
 * kiedy i jakie odpowiedzi zostaną wysłane.
 * 
 * Szablon powinien być stosowany do usług, w których można z góry określić jakie treści będą
 * odsyłane klientowi.
 * 
 * Szablon zawarty jest w pliku template_200_delayedReply.php. Zalecamy skopiowanie treści szablonu do
 * pliku index.php i wprowadzenie własnej obsługi wiadomości w wyznaczonym miejscu.
 * 
 * Wymagane ingerencje w treść zaznaczone są ciągami znaków todo.
 *
 */

require_once 'smsGatewaySoap/cashbillSms.php';
require_once 'smsGatewaySoap/messageLogger.php';

class cSMSDelayedReply implements iSmsHandler 
{
	function handle( cMessageSMSIn $sms )
	{
		
		/*
		 * @todo: dodać określenie odpowiedzi, która powinna zostać odesłana do klienta
		 * 
		 * Treść przysłanej wiadomości znajduje się w $sms->text
		 * 
		 * Szczegółowe dane o wysłanej wiadomości (numer klienta, czas wysłania, identyfikatory)
		 * udokumentowane są w klasie cMessageSMSIn.
		 * 
		 */
		
		// zastąpienie znaków poza literami i cyframi kropkami. obcięcie białych znaków z początku i końca oraz zamienienie treści na same małe litery.
		$parsedText = preg_replace( '/[^a-z0-9]/', '.', strtolower( trim( $sms->text ) ) );
		
		// rozdzielenie przysłaniej treści na identyfikator usługi i wariant wybrany przez użytkownika
		list( $prefix, $selectedService ) = explode( '.', $parsedText ); 
		
		if ( !$selectedService )
		{
			// korzystanie z metody "reply" zapewnia automatyczne przydzielenie unikalnego identyfikatora, wymaganego przez system Cashbill
			// "1" to numer odpowiedzi, wymagany by poprawnie utworzyć identyfikator
			$sms->reply( 'Dziękujemy za zgłoszenie. Za godzinę otrzymasz pytanie', 1 )->send();
			$sms->reply( 'Twoje pytanie: Ile jest 2+2? Odpowiedź w formacie przyklad.4 wyślij na numer 71880', 2, time()+3600 )->send();
		}
		elseif ( $selectedService == '4' )
		{
			$sms->reply( 'Dobra odpowiedź!', 1 )->send();
		}
		else
		{
			$sms->reply( 'Zła odpowiedź! Spróbuj ponownie!', 1 )->send();
		}
	}
	
}

/*
 * @todo: uzupełnić klucz tajny i prefiks (identyfikator usługi).
 * Dane te można odczytać z panelu administracyjnego Cashbill, po
 * wybraniu zatwierdzonej usługi SMS.
 * 
 */
$smsGateway = new cGateway( '<twoj klucz tajny>', '<prefiks usługi>' );

/*
 * Poniżej znajduje się sekcja uruchamiająca loggery diagnostyczne,
 * zapisujące wszystkie informacje o transmisji SMS do pliku
 * (domyślnie log/sms.log). Loggery można usunąć bez wpływu na działanie
 * systemu, jednak zalecamy pozostawienie ich w celach diagnostycznych.
 * 
 *  @todo: zdecydować, czy logowanie jest potrzebne
 */
$smsGateway->addReportHandler  ( new cReportLogger()   );
$smsGateway->addSMSHandler     ( new cSMSLogger()      );
$smsGateway->addSMSErrorHandler( new cSMSErrorLogger() );

/*
 * Poniższa sekcja uruchamia właściwą obsługę wiadomości SMS.
 */
$smsGateway->addSMSHandler( new cSMSDelayedReply() );
$smsGateway->handleInput();


?>